﻿using System;
using System.Collections;
using System.Windows;

using DevExpress.Xpf.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.gridControl.ItemsSource = new NorthwindEntities().Products;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 그리드 컨트롤 커스텀 컬럼 그룹 처리하기 - gridControl_CustomColumnGroup(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 컬럼 그룹 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomColumnGroup(object sender, CustomColumnSortEventArgs e)
        {
            if(e.Column != null & e.Column.FieldName == "UnitPrice")
            {
                double value1 = Math.Floor(Convert.ToDouble(e.Value1) / 10);
                double value2 = Math.Floor(Convert.ToDouble(e.Value2) / 10);
                int    result = Comparer.Default.Compare(value1, value2);

                if(value1 > 9 && value2 > 9)
                {
                    result = 0;
                }

                e.Result  = result;
                e.Handled = true;
            }
        }

        #endregion
        #region 그리드 컨트롤 커스텀 그룹 표시 텍스트 처리하기 - gridControl_CustomGroupDisplayText(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 그룹 표시 텍스트 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomGroupDisplayText(object sender, CustomGroupDisplayTextEventArgs e)
        {
            if(e.Column == null)
            {
                return;
            }

            if(e.Column.FieldName == "UnitPrice")
            {
                string displayText = GetDisplayText(this.gridControl.GetGroupRowValue(e.RowHandle));

                e.DisplayText = displayText;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 표시 텍스트 구하기 - GetDisplayText(valueObject)

        /// <summary>
        /// 표시 텍스트 구하기
        /// </summary>
        /// <param name="valueObject">값 객체</param>
        /// <returns>표시 텍스트</returns>
        private static string GetDisplayText(object valueObject)
        {
            double value = Math.Floor(Convert.ToDouble(valueObject) / 10);

            string displayText;

            if(value > 9)
            {
                displayText = string.Format(">= {0:c} ", 100);
            }
            else 
            {
                displayText = string.Format("{0:c} - {1:c}", value * 10, (value + 1) * 10);
            }

            return displayText;
        }

        #endregion
    }
}